@@ -17,7 +17,7 @@
 
 """Command-line script that runs a server over roundup.cgi.client.
 
-$Id: roundup_server.py,v 1.94 2007/09/25 04:27:12 jpend Exp $
+$Id: roundup_server.py,v 1.94 2007-09-25 04:27:12 jpend Exp $
 """
 __docformat__ = 'restructuredtext'
 
@@ -29,6 +29,8 @@ try:
 except ImportError:
     SSL = None
 
+from time import sleep
+
 # python version check
 from roundup import configuration, version_check
 from roundup import __version__ as roundup_version
@@ -127,9 +129,18 @@ class SecureHTTPServer(BaseHTTPServer.HTTPServer):
                         try:
                             line = self.__fileobj.readline(*args)
                         except SSL.WantReadError:
+                            sleep (.1)
                             line = None
                     return line
 
+                def read(self, *args):
+                    """ SSL.Connection can return WantRead """
+                    while True:
+                        try:
+                            return self.__fileobj.read(*args)
+                        except SSL.WantReadError:
+                            sleep (.1)
+
                 def __getattr__(self, attrib):
                     return getattr(self.__fileobj, attrib)
 
